/*
    Add user id in top panel
    GNOME Shell 45+ extension 
    (c) fthx 2023
    License: GPL v3
*/


import Clutter from 'gi://Clutter';
import GLib from 'gi://GLib';
import GObject from 'gi://GObject';
import St from 'gi://St';

import * as Main from 'resource:///org/gnome/shell/ui/main.js';
import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
import * as Util from 'resource:///org/gnome/shell/misc/util.js';


var UserIdMenu = GObject.registerClass(
class UserIdMenu extends PanelMenu.Button {
    _init() {
        super._init('UserIdMenu')
        this.box = new St.BoxLayout({style_class: 'panel-status-menu-box'});
        this.user_id = new St.Label({text: GLib.get_real_name() + " :: " + GLib.get_user_name() + "@" + GLib.get_host_name(), y_align: Clutter.ActorAlign.CENTER, style_class: "user-label"});
        this.box.add_child(this.user_id);
        this.add_child(this.box);
    }
});

export default class UserIdExtension {
    constructor() {
    }

    enable() {
        this.user_id_indicator = new UserIdMenu();
        Main.panel.addToStatusArea('user-id-menu', this.user_id_indicator, 1);
        this.user_id_indicator.connect('button-release-event', (widget, event) => Util.trySpawnCommandLine("gnome-control-center user-accounts"));
    }

    disable() {
        this.user_id_indicator.destroy();
        this.user_id_indicator = null;
    }
}
